@@ -41,15 +41,16 @@ class Instrument:
 				self.track + self.bar
 			b = Bar()
 			b.set_meter(state["meter"])
+			b.length = 0.0
 			b.key = state["key"]
 			self.bar = b
 		
 		dur = state["resolution"]
 		if state["swing"]:
 			if state["tick"] % 2 == 0:
-				dur *= 1.33
+				dur *= (2.0 / 3.0)
 			else:
-				dur *= 0.66
+				dur *= (4.0 / 3.0)
 		if len(self.bar) > 0:
 			if self.bar[0][2] is None:
 				i = 1 / (1.0 / dur + \
@@ -91,9 +92,9 @@ class Instrument:
 		dur = state["resolution"]
 		if state["swing"]:
 			if state["tick"] % 2 == 0:
-				dur *= 0.66
+				dur *= (2.0 / 3.0)
 			else:
-				dur *= 1.33
+				dur *= (4.0 / 3.0)
 
 		n = self.generate_note(state)
 		v = self.generate_velocity(state)
@@ -123,7 +124,6 @@ class Instrument:
 					i = 1 / (1.0 / dur + \
 						1.0 / self.bar[-1][1])
 					self.bar[-1][1] = i
-					print i
 				else:
 					self.bar.place_notes(None, dur)
 			else:
